@@ -43,13 +43,13 @@ enum DIALOG_TYPE {FIND_DLG, REPLACE_DLG, FINDINFILES_DLG, FINDINPROJECTS_DLG, MA
 enum InWhat{ALL_OPEN_DOCS, FILES_IN_DIR, CURRENT_DOC, CURR_DOC_SELECTION, FILES_IN_PROJECTS};
 
 struct FoundInfo {
-	FoundInfo(intptr_t start, intptr_t end, size_t lineNumber, const TCHAR *fullPath)
+	FoundInfo(intptr_t start, intptr_t end, size_t lineNumber, const wchar_t *fullPath)
 		: _lineNumber(lineNumber), _fullPath(fullPath) {
 		_ranges.push_back(std::pair<intptr_t, intptr_t>(start, end));
 	};
 	std::vector<std::pair<intptr_t, intptr_t>> _ranges;
 	size_t _lineNumber = 0;
-	generic_string _fullPath;
+	std::wstring _fullPath;
 };
 
 struct TargetRange {
@@ -72,10 +72,10 @@ struct FindOption
 	bool _doPurge = false;
 	bool _doMarkLine = false;
 	bool _isInSelection = false;
-	generic_string _str2Search;
-	generic_string _str4Replace;
-	generic_string _filters;
-	generic_string _directory;
+	std::wstring _str2Search;
+	std::wstring _str4Replace;
+	std::wstring _filters;
+	std::wstring _directory;
 	bool _isRecursive = true;
 	bool _isInHiddenDir = false;
 	bool _isProjectPanel_1 = false;
@@ -88,7 +88,7 @@ struct FindOption
 //This class contains generic search functions as static functions for easy access
 class Searching {
 public:
-	static int convertExtendedToString(const TCHAR * query, TCHAR * result, int length);
+	static int convertExtendedToString(const wchar_t * query, wchar_t * result, int length);
 	static TargetRange t;
 	static int buildSearchFlags(const FindOption * option) {
 		return	(option->_isWholeWord ? SCFIND_WHOLEWORD : 0) |
@@ -99,7 +99,7 @@ public:
 	static void displaySectionCentered(size_t posStart, size_t posEnd, ScintillaEditView * pEditView, bool isDownwards = true);
 
 private:
-	static bool readBase(const TCHAR * str, int * value, int base, int size);
+	static bool readBase(const wchar_t * str, int * value, int base, int size);
 
 };
 
@@ -121,11 +121,11 @@ public:
 		_ppEditView = ppEditView;
 	};
 
-	void addSearchLine(const TCHAR *searchName);
-	void addFileNameTitle(const TCHAR * fileName);
+	void addSearchLine(const wchar_t *searchName);
+	void addFileNameTitle(const wchar_t * fileName);
 	void addFileHitCount(int count);
 	void addSearchResultInfo(int count, int countSearched, bool searchedEntireNotSelection, const FindOption *pFindOpt);
-	const char* foundLine(FoundInfo fi, SearchResultMarkingLine mi, const TCHAR* foundline, size_t totalLineNumber);
+	const char* foundLine(FoundInfo fi, SearchResultMarkingLine mi, const wchar_t* foundline, size_t totalLineNumber);
 	void setFinderStyle();
 	void setFinderStyleForNpc(bool onlyColor = false);
 	void removeAll();
@@ -140,10 +140,10 @@ public:
 	void gotoNextFoundResult(int direction);
 	std::pair<intptr_t, intptr_t> gotoFoundLine(size_t nOccurrence = 0); // value 0 means this argument is not used
 	void deleteResult();
-	std::vector<generic_string> getResultFilePaths() const;
-	bool canFind(const TCHAR *fileName, size_t lineNumber, size_t* indexToStartFrom) const;
+	std::vector<std::wstring> getResultFilePaths() const;
+	bool canFind(const wchar_t *fileName, size_t lineNumber, size_t* indexToStartFrom) const;
 	void setVolatiled(bool val) { _canBeVolatiled = val; };
-	generic_string getHitsString(int count) const;
+	std::wstring getHitsString(int count) const;
 
 	LRESULT scintillaExecute(UINT msg, WPARAM wParam = 0, LPARAM lParam = 0) const {
 		return _scintView.execute(msg, wParam, lParam);
@@ -182,14 +182,14 @@ private:
 	bool _longLinesAreWrapped = false;
 	bool _purgeBeforeEverySearch = false;
 
-	generic_string _prefixLineStr;
+	std::wstring _prefixLineStr;
 
 	void setFinderReadOnly(bool isReadOnly) {
 		_scintView.execute(SCI_SETREADONLY, isReadOnly);
 	};
 
-	bool isLineActualSearchResult(const generic_string & s) const;
-	generic_string & prepareStringForClipboard(generic_string & s) const;
+	bool isLineActualSearchResult(const std::wstring & s) const;
+	std::wstring & prepareStringForClipboard(std::wstring & s) const;
 
 	static FoundInfo EmptyFoundInfo;
 	static SearchResultMarkingLine EmptySearchResultMarking;
@@ -209,8 +209,8 @@ enum FindNextType {
 
 struct FindReplaceInfo
 {
-	const TCHAR *_txt2find = nullptr;
-	const TCHAR *_txt2replace = nullptr;
+	const wchar_t *_txt2find = nullptr;
+	const wchar_t *_txt2replace = nullptr;
 	intptr_t _startRange = -1;
 	intptr_t _endRange = -1;
 };
@@ -219,7 +219,7 @@ struct FindersInfo
 {
 	Finder *_pSourceFinder = nullptr;
 	Finder *_pDestFinder = nullptr;
-	const TCHAR *_pFileName = nullptr;
+	const wchar_t *_pFileName = nullptr;
 
 	FindOption _findOption;
 };
@@ -272,10 +272,10 @@ public :
 	void initOptionsFromDlg();
 
 	void doDialog(DIALOG_TYPE whichType, bool isRTL = false, bool toShow = true);
-	bool processFindNext(const TCHAR *txt2find, const FindOption *options = NULL, FindStatus *oFindStatus = NULL, FindNextType findNextType = FINDNEXTTYPE_FINDNEXT);
-	bool processReplace(const TCHAR *txt2find, const TCHAR *txt2replace, const FindOption *options = NULL);
+	bool processFindNext(const wchar_t *txt2find, const FindOption *options = NULL, FindStatus *oFindStatus = NULL, FindNextType findNextType = FINDNEXTTYPE_FINDNEXT);
+	bool processReplace(const wchar_t *txt2find, const wchar_t *txt2replace, const FindOption *options = NULL);
 
-	int markAll(const TCHAR *txt2find, int styleID);
+	int markAll(const wchar_t *txt2find, int styleID);
 	int markAllInc(const FindOption *opt);
 	
 
@@ -284,7 +284,7 @@ public :
 
 	void replaceAllInOpenedDocs();
 	void findAllIn(InWhat op);
-	void setSearchText(TCHAR * txt2find);
+	void setSearchText(wchar_t * txt2find);
 
 	void gotoNextFoundResult(int direction = 0) const {
 		if (_pFinder) _pFinder->gotoNextFoundResult(direction);
@@ -293,10 +293,10 @@ public :
 	void putFindResult(int result) {
 		_findAllResult = result;
 	};
-	const TCHAR * getDir2Search() const {return _env->_directory.c_str();};
+	const wchar_t * getDir2Search() const {return _env->_directory.c_str();};
 
-	void getPatterns(std::vector<generic_string> & patternVect);
-	void getAndValidatePatterns(std::vector<generic_string> & patternVect);
+	void getPatterns(std::vector<std::wstring> & patternVect);
+	void getAndValidatePatterns(std::vector<std::wstring> & patternVect);
 
 	void launchFindInFilesDlg() {
 		doDialog(FINDINFILES_DLG);
@@ -306,16 +306,16 @@ public :
 		doDialog(FINDINPROJECTS_DLG);
 	};
 
-	void setFindInFilesDirFilter(const TCHAR *dir, const TCHAR *filters);
+	void setFindInFilesDirFilter(const wchar_t *dir, const wchar_t *filters);
 	void setProjectCheckmarks(FindHistory *findHistory, int Msk);
 	void enableProjectCheckmarks();
 
-	generic_string getText2search() const {
+	std::wstring getText2search() const {
 		return _env->_str2Search;
 	};
 
-	const generic_string & getFilters() const {return _env->_filters;};
-	const generic_string & getDirectory() const {return _env->_directory;};
+	const std::wstring & getFilters() const {return _env->_filters;};
+	const std::wstring & getDirectory() const {return _env->_directory;};
 	const FindOption & getCurrentOptions() const {return *_env;};
 	bool isRecursive() const { return _env->_isRecursive; };
 	bool isInHiddenDir() const { return _env->_isInHiddenDir; };
@@ -323,13 +323,13 @@ public :
 	bool isProjectPanel_2() const { return _env->_isProjectPanel_2; };
 	bool isProjectPanel_3() const { return _env->_isProjectPanel_3; };
 	void saveFindHistory();
-	void changeTabName(DIALOG_TYPE index, const TCHAR *name2change) {
+	void changeTabName(DIALOG_TYPE index, const wchar_t *name2change) {
 		TCITEM tie{};
 		tie.mask = TCIF_TEXT;
-		tie.pszText = (TCHAR *)name2change;
+		tie.pszText = (wchar_t *)name2change;
 		TabCtrl_SetItem(_tab.getHSelf(), index, &tie);
 
-		TCHAR label[MAX_PATH]{};
+		wchar_t label[MAX_PATH]{};
 		_tab.getCurrentTitle(label, MAX_PATH);
 		::SetWindowText(_hSelf, label);
 	}
@@ -389,16 +389,18 @@ public :
 		}
 	};
 
-	void execSavedCommand(int cmd, uptr_t intValue, const generic_string& stringValue);
+	void execSavedCommand(int cmd, uptr_t intValue, const std::wstring& stringValue);
 	void clearMarks(const FindOption& opt);
 	void setStatusbarMessage(const std::wstring & msg, FindStatus staus, std::wstring tooltipMsg = L"");
 	void setStatusbarMessageWithRegExprErr(ScintillaEditView* pEditView);
-	generic_string getScopeInfoForStatusBar(FindOption const *pFindOpt) const;
+	std::wstring getScopeInfoForStatusBar(FindOption const *pFindOpt) const;
 	Finder * createFinder();
 	bool removeFinder(Finder *finder2remove);
 	DIALOG_TYPE getCurrentStatus() {return _currentStatus;};
 	Finder* getFinderFrom(HWND hwnd);
 
+	int regexBackwardMsgBox();
+
 protected :
 	void resizeDialogElements();
 	intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) override;
@@ -422,7 +424,7 @@ private:
 
 	ScintillaEditView** _ppEditView = nullptr;
 	Finder  *_pFinder = nullptr;
-	generic_string _findResTitle;
+	std::wstring _findResTitle;
 
 	std::vector<Finder*> _findersOfFinder{};
 
@@ -433,7 +435,7 @@ private:
 	bool _isRTL = false;
 
 	int _findAllResult = 0;
-	TCHAR _findAllResultStr[1024] = {'\0'};
+	wchar_t _findAllResultStr[1024] = {'\0'};
 
 	int _fileNameLenMax = 1024;
 	char *_uniFileName = nullptr;
@@ -443,7 +445,7 @@ private:
 	StatusBar _statusBar;
 	FindStatus _statusbarFindStatus;
 
-	generic_string _statusbarTooltipMsg;
+	std::wstring _statusbarTooltipMsg;
 	HWND _statusbarTooltipWnd = nullptr;
 	HICON _statusbarTooltipIcon = nullptr;
 	int _statusbarTooltipIconSize = 0;
@@ -458,7 +460,7 @@ private:
 	std::vector<int> _reduce2hide_findReplace = { IDC_IN_SELECTION_CHECK, IDC_REPLACEINSELECTION, IDREPLACEALL, IDCANCEL };
 	std::vector<int> _reduce2hide_fif = { IDD_FINDINFILES_FILTERS_STATIC, IDD_FINDINFILES_FILTERS_COMBO, IDCANCEL };
 	std::vector<int> _reduce2hide_fip = { IDD_FINDINFILES_FILTERS_STATIC, IDD_FINDINFILES_FILTERS_COMBO, IDCANCEL };
-	std::vector<int> _reduce2hide_mark = { IDC_MARKLINE_CHECK, IDC_PURGE_CHECK, IDC_IN_SELECTION_CHECK, IDC_COPY_MARKED_TEXT, IDCANCEL };
+	std::vector<int> _reduce2hide_mark = { IDC_MARKLINE_CHECK, IDC_PURGE_CHECK, IDC_IN_SELECTION_CHECK, IDC_REPLACEINSELECTION, IDC_COPY_MARKED_TEXT, IDCANCEL };
 
 	void enableFindDlgItem(int dlgItemID, bool isEnable = true);
 	void showFindDlgItem(int dlgItemID, bool isShow = true);
@@ -489,8 +491,8 @@ private:
 	void updateCombos();
 	void updateCombo(int comboID);
 	void fillFindHistory();
-	void fillComboHistory(int id, const std::vector<generic_string> & strings);
-	int saveComboHistory(int id, int maxcount, std::vector<generic_string> & strings, bool saveEmpty);
+	void fillComboHistory(int id, const std::vector<std::wstring> & strings);
+	int saveComboHistory(int id, int maxcount, std::vector<std::wstring> & strings, bool saveEmpty);
 	static const int FR_OP_FIND = 1;
 	static const int FR_OP_REPLACE = 2;
 	static const int FR_OP_FIF = 4;
@@ -498,7 +500,7 @@ private:
 	static const int FR_OP_FIP = 16;
 	void saveInMacro(size_t cmd, int cmdType);
 	void drawItem(LPDRAWITEMSTRUCT lpDrawItemStruct);
-	bool replaceInFilesConfirmCheck(generic_string directory, generic_string fileTypes);
+	bool replaceInFilesConfirmCheck(std::wstring directory, std::wstring fileTypes);
 	bool replaceInProjectsConfirmCheck();
 	bool replaceInOpenDocsConfirmCheck(void);
 
@@ -521,7 +523,7 @@ public :
 	void destroy() override;
 	void display(bool toShow = true) const override;
 
-	void setSearchText(const TCHAR* txt2find, bool) {
+	void setSearchText(const wchar_t* txt2find, bool) {
 		::SendDlgItemMessage(_hSelf, IDC_INCFINDTEXT, WM_SETTEXT, 0, reinterpret_cast<LPARAM>(txt2find));
 	};
 
@@ -555,7 +557,7 @@ public:
 	Progress(const Progress&) = delete;
 	const Progress& operator=(const Progress&) = delete;
 
-	HWND open(HWND hCallerWnd, const TCHAR* header = NULL);
+	HWND open(HWND hCallerWnd, const wchar_t* header = NULL);
 	void close();
 
 	bool isCancelled() const
@@ -565,12 +567,12 @@ public:
 		return false;
 	}
 
-	void setPercent(unsigned percent, const TCHAR* fileName, int nbHitsSoFar) const;
-	void setInfo(const TCHAR* info, int nbHitsSoFar = -1) const;
+	void setPercent(unsigned percent, const wchar_t* fileName, int nbHitsSoFar) const;
+	void setInfo(const wchar_t* info, int nbHitsSoFar = -1) const;
 
 private:
-	static const TCHAR cClassName[];
-	static const TCHAR cDefaultHeader[];
+	static const wchar_t cClassName[];
+	static const wchar_t cDefaultHeader[];
 	static const int cBackgroundColor;
 	static const SIZE _szClient;
 
@@ -589,7 +591,7 @@ private:
 	HINSTANCE _hInst = nullptr;
 	volatile HWND _hwnd = nullptr;
 	HWND _hCallerWnd = nullptr;
-	TCHAR _header[128] = {'\0'};
+	wchar_t _header[128] = {'\0'};
 	HANDLE _hThread = nullptr;
 	HANDLE _hActiveState = nullptr;
 	HWND _hPathText = nullptr;
