@@ -47,9 +47,9 @@ distribution.
 #endif
 
 #ifdef TIXML_USE_STL
-	#define TIXML_STRING	generic_string
-	#define TIXML_ISTREAM	std::basic_istream<TCHAR>
-	#define TIXML_OSTREAM	std::basic_ostream<TCHAR>
+	#define TIXML_STRING	std::wstring
+	#define TIXML_ISTREAM	std::basic_istream<wchar_t>
+	#define TIXML_OSTREAM	std::basic_ostream<wchar_t>
 #else
 	#include "tinystr.h"
 	#define TIXML_STRING	TiXmlString
@@ -174,11 +174,11 @@ protected:
 	  public:
 		StringToBuffer( const TIXML_STRING& str );
 		~StringToBuffer();
-		TCHAR* buffer;
+		wchar_t* buffer;
 	};
 
-	static const TCHAR*	SkipWhiteSpace( const TCHAR* );
-	inline static bool	IsWhiteSpace( int c )		{ return ( _istspace( static_cast<TCHAR>(c) ) || c == '\n' || c == '\r' ); }
+	static const wchar_t*	SkipWhiteSpace( const wchar_t* );
+	inline static bool	IsWhiteSpace( int c )		{ return ( _istspace( static_cast<wchar_t>(c) ) || c == '\n' || c == '\r' ); }
 
 	virtual void StreamOut (TIXML_OSTREAM *) const = 0;
 
@@ -187,28 +187,28 @@ protected:
 	    static bool StreamTo( TIXML_ISTREAM * in, int character, TIXML_STRING * tag );
 	#endif
 
-	/*	Reads an XML name into the generic_string provided. Returns
+	/*	Reads an XML name into the std::wstring provided. Returns
 		a pointer just past the last character of the name,
 		or 0 if the function has an error.
 	*/
-	static const TCHAR* ReadName( const TCHAR* p, TIXML_STRING* name );
+	static const wchar_t* ReadName( const wchar_t* p, TIXML_STRING* name );
 
 	/*	Reads text. Returns a pointer past the given end tag.
 		Wickedly complex options, but it keeps the (sensitive) code in one place.
 	*/
-	static const TCHAR* ReadText(	const TCHAR* in,				// where to start
-									TIXML_STRING* text,			// the generic_string read
+	static const wchar_t* ReadText(	const wchar_t* in,				// where to start
+									TIXML_STRING* text,			// the std::wstring read
 									bool ignoreWhiteSpace,		// whether to keep the white space
-									const TCHAR* endTag,			// what ends this text
+									const wchar_t* endTag,			// what ends this text
 									bool ignoreCase );			// whether to ignore case in the end tag
 
-	virtual const TCHAR* Parse( const TCHAR* p, TiXmlParsingData* data ) = 0;
+	virtual const wchar_t* Parse( const wchar_t* p, TiXmlParsingData* data ) = 0;
 
 	// If an entity has been found, transform it into a character.
-	static const TCHAR* GetEntity( const TCHAR* in, TCHAR* value );
+	static const wchar_t* GetEntity( const wchar_t* in, wchar_t* value );
 
 	// Get a character, while interpreting entities.
-	inline static const TCHAR* GetChar( const TCHAR* p, TCHAR* _value )
+	inline static const wchar_t* GetChar( const wchar_t* p, wchar_t* _value )
 	{
 		assert( p );
 		if ( *p == '&' )
@@ -222,15 +222,15 @@ protected:
 		}
 	}
 
-	// Puts a generic_string to a stream, expanding entities as it goes.
+	// Puts a std::wstring to a stream, expanding entities as it goes.
 	// Note this should not contian the '<', '>', etc, or they will be transformed into entities!
 	static void PutString( const TIXML_STRING& str, TIXML_OSTREAM* out );
 
 	static void PutString( const TIXML_STRING& str, TIXML_STRING* out );
 
 	// Return true if the next characters in the stream are any of the endTag sequences.
-	static bool StringEqual(	const TCHAR* p,
-								const TCHAR* endTag,
+	static bool StringEqual(	const wchar_t* p,
+								const wchar_t* endTag,
 								bool ignoreCase );
 
 
@@ -253,16 +253,16 @@ protected:
 
 		TIXML_ERROR_STRING_COUNT
 	};
-	static const TCHAR* errorString[ TIXML_ERROR_STRING_COUNT ];
+	static const wchar_t* errorString[ TIXML_ERROR_STRING_COUNT ];
 
 	TiXmlCursor location;
 
 private:
 	struct Entity
 	{
-		const TCHAR*     str;
+		const wchar_t*     str;
 		unsigned int	strLength;
-		TCHAR		    chr;
+		wchar_t		    chr;
 	};
 	enum
 	{
@@ -292,7 +292,7 @@ public:
 	    /** An input stream operator, for every class. Tolerant of newlines and
 		    formatting, but doesn't expect them.
 	    */
-	    friend std::basic_istream<TCHAR>& operator >> (std::basic_istream<TCHAR>& in, TiXmlNode& base);
+	    friend std::basic_istream<wchar_t>& operator >> (std::basic_istream<wchar_t>& in, TiXmlNode& base);
 
 	    /** An output stream operator, for every class. Note that this outputs
 		    without any newlines or formatting, as opposed to Print(), which
@@ -310,10 +310,10 @@ public:
 		    A TiXmlDocument will read nodes until it reads a root element, and
 			all the children of that root element.
 	    */	
-	    friend std::basic_ostream<TCHAR>& operator<< (std::basic_ostream<TCHAR>& out, const TiXmlNode& base);
+	    friend std::basic_ostream<wchar_t>& operator<< (std::basic_ostream<wchar_t>& out, const TiXmlNode& base);
 
 		/// Appends the XML node or attribute to a string.
-		friend generic_string& operator<< (generic_string& out, const TiXmlNode& base );
+		friend std::wstring& operator<< (std::wstring& out, const TiXmlNode& base );
 
 	#else
 	    // Used internally, not part of the public API.
@@ -343,12 +343,12 @@ public:
 		Element:	name of the element
 		Comment:	the comment text
 		Unknown:	the tag contents
-		Text:		the text generic_string
+		Text:		the text std::wstring
 		@endverbatim
 
 		The subclasses will wrap this function.
 	*/
-	const TCHAR * Value() const { return value.c_str (); }
+	const wchar_t * Value() const { return value.c_str (); }
 
 	/** Changes the value of the node. Defined as:
 		@verbatim
@@ -356,14 +356,14 @@ public:
 		Element:	name of the element
 		Comment:	the comment text
 		Unknown:	the tag contents
-		Text:		the text generic_string
+		Text:		the text std::wstring
 		@endverbatim
 	*/
-	void SetValue(const TCHAR * _value) { value = _value;}
+	void SetValue(const wchar_t * _value) { value = _value;}
 
     #ifdef TIXML_USE_STL
 	/// STL string form.
-	void SetValue( const generic_string& _value )    
+	void SetValue( const std::wstring& _value )    
 	{	  
 		StringToBuffer buf( _value );
 		SetValue( buf.buffer ? buf.buffer : TEXT("") );    	
@@ -377,14 +377,14 @@ public:
 	TiXmlNode* Parent() const					{ return parent; }
 
 	TiXmlNode* FirstChild()	const	{ return firstChild; }		///< The first child of this node. Will be null if there are no children.
-	TiXmlNode* FirstChild( const TCHAR * value ) const;			///< The first child of this node with the matching 'value'. Will be null if none found.
+	TiXmlNode* FirstChild( const wchar_t * value ) const;			///< The first child of this node with the matching 'value'. Will be null if none found.
 
 	TiXmlNode* LastChild() const	{ return lastChild; }		/// The last child of this node. Will be null if there are no children.
-	TiXmlNode* LastChild( const TCHAR * value ) const;			/// The last child of this node matching 'value'. Will be null if there are no children.
+	TiXmlNode* LastChild( const wchar_t * value ) const;			/// The last child of this node matching 'value'. Will be null if there are no children.
 
     #ifdef TIXML_USE_STL
-	TiXmlNode* FirstChild( const generic_string& _value ) const	{	return FirstChild (_value.c_str ());	}	///< STL std::generic_string form.
-	TiXmlNode* LastChild( const generic_string& _value ) const		{	return LastChild (_value.c_str ());	}	///< STL std::generic_string form.
+	TiXmlNode* FirstChild( const std::wstring& _value ) const	{	return FirstChild (_value.c_str ());	}	///< STL std::std::wstring form.
+	TiXmlNode* LastChild( const std::wstring& _value ) const		{	return LastChild (_value.c_str ());	}	///< STL std::std::wstring form.
 	#endif
 
 	/** An alternate way to walk the children of a node.
@@ -406,10 +406,10 @@ public:
 	TiXmlNode* IterateChildren( TiXmlNode* previous ) const;
 
 	/// This flavor of IterateChildren searches for children with a particular 'value'
-	TiXmlNode* IterateChildren( const TCHAR * value, TiXmlNode* previous ) const;
+	TiXmlNode* IterateChildren( const wchar_t * value, TiXmlNode* previous ) const;
 
     #ifdef TIXML_USE_STL
-	TiXmlNode* IterateChildren( const generic_string& _value, TiXmlNode* previous ) const	{	return IterateChildren (_value.c_str (), previous);	}	///< STL std::generic_string form.
+	TiXmlNode* IterateChildren( const std::wstring& _value, TiXmlNode* previous ) const	{	return IterateChildren (_value.c_str (), previous);	}	///< STL std::std::wstring form.
 	#endif
 
 	/** Add a new node related to this. Adds a child past the LastChild.
@@ -451,18 +451,18 @@ public:
 	TiXmlNode* PreviousSibling() const			{ return prev; }
 
 	/// Navigate to a sibling node.
-	TiXmlNode* PreviousSibling( const TCHAR * ) const;
+	TiXmlNode* PreviousSibling( const wchar_t * ) const;
 
     #ifdef TIXML_USE_STL
-	TiXmlNode* PreviousSibling( const generic_string& _value ) const	{	return PreviousSibling (_value.c_str ());	}	///< STL std::generic_string form.
-	TiXmlNode* NextSibling( const generic_string& _value) const		{	return NextSibling (_value.c_str ());	}	///< STL std::generic_string form.
+	TiXmlNode* PreviousSibling( const std::wstring& _value ) const	{	return PreviousSibling (_value.c_str ());	}	///< STL std::std::wstring form.
+	TiXmlNode* NextSibling( const std::wstring& _value) const		{	return NextSibling (_value.c_str ());	}	///< STL std::std::wstring form.
 	#endif
 
 	/// Navigate to a sibling node.
 	TiXmlNode* NextSibling() const				{ return next; }
 
 	/// Navigate to a sibling node with the given 'value'.
-	TiXmlNode* NextSibling( const TCHAR * ) const;
+	TiXmlNode* NextSibling( const wchar_t * ) const;
 
 	/** Convenience function to get through elements.
 		Calls NextSibling and ToElement. Will skip all non-Element
@@ -474,20 +474,20 @@ public:
 		Calls NextSibling and ToElement. Will skip all non-Element
 		nodes. Returns 0 if there is not another element.
 	*/
-	TiXmlElement* NextSiblingElement( const TCHAR * ) const;
+	TiXmlElement* NextSiblingElement( const wchar_t * ) const;
 
     #ifdef TIXML_USE_STL
-	TiXmlElement* NextSiblingElement( const generic_string& _value) const	{	return NextSiblingElement (_value.c_str ());	}	///< STL std::generic_string form.
+	TiXmlElement* NextSiblingElement( const std::wstring& _value) const	{	return NextSiblingElement (_value.c_str ());	}	///< STL std::std::wstring form.
 	#endif
 
 	/// Convenience function to get through elements.
 	TiXmlElement* FirstChildElement()	const;
 
 	/// Convenience function to get through elements.
-	TiXmlElement* FirstChildElement( const TCHAR * value ) const;
+	TiXmlElement* FirstChildElement( const wchar_t * value ) const;
 
     #ifdef TIXML_USE_STL
-	TiXmlElement* FirstChildElement( const generic_string& _value ) const	{	return FirstChildElement (_value.c_str ());	}	///< STL std::generic_string form.
+	TiXmlElement* FirstChildElement( const std::wstring& _value ) const	{	return FirstChildElement (_value.c_str ());	}	///< STL std::std::wstring form.
 	#endif
 
 	/** Query the type (as an enumerated value, above) of this node.
@@ -525,7 +525,7 @@ protected:
 	#endif
 
 	// Figure out what is at *p, and parse it. Returns null if it is not an xml node.
-	TiXmlNode* Identify( const TCHAR* start );
+	TiXmlNode* Identify( const wchar_t* start );
 	void CopyToClone( TiXmlNode* target ) const	{ target->SetValue (value.c_str() );
 												  target->userData = userData; }
 
@@ -567,7 +567,7 @@ public:
 
 	#ifdef TIXML_USE_STL
 	/// string constructor.
-	TiXmlAttribute( const generic_string& _name, const generic_string& _value )
+	TiXmlAttribute( const std::wstring& _name, const std::wstring& _value )
 	{
 		name = _name;
 		value = _value;
@@ -577,7 +577,7 @@ public:
 	#endif
 
 	/// Construct an attribute with a name and value.
-	TiXmlAttribute( const TCHAR * _name, const TCHAR * _value )
+	TiXmlAttribute( const wchar_t * _name, const wchar_t * _value )
 	{
 		name = _name;
 		value = _value;
@@ -585,12 +585,12 @@ public:
 		prev = next = 0;
 	}
 
-	const TCHAR*        Name()  const		{ return name.c_str (); }		///< Return the name of this attribute.
-	const TCHAR*        Value() const		{ return value.c_str (); }		///< Return the value of this attribute.
+	const wchar_t*        Name()  const		{ return name.c_str (); }		///< Return the name of this attribute.
+	const wchar_t*        Value() const		{ return value.c_str (); }		///< Return the value of this attribute.
 	int                 IntValue() const;									///< Return the value of this attribute, converted to an integer.
 	double              DoubleValue() const;								///< Return the value of this attribute, converted to a double.
 
-	/** QueryIntValue examines the value generic_string. It is an alternative to the
+	/** QueryIntValue examines the value std::wstring. It is an alternative to the
 		IntValue() method with richer error checking.
 		If the value is an integer, it is stored in 'value' and 
 		the call returns TIXML_SUCCESS. If it is not
@@ -600,24 +600,24 @@ public:
 		which is the opposite of almost all other TinyXml calls.
 	*/
 	int QueryIntValue( int* value ) const;
-	/// QueryDoubleValue examines the value generic_string. See QueryIntValue().
+	/// QueryDoubleValue examines the value std::wstring. See QueryIntValue().
 	int QueryDoubleValue( double* value ) const;
 
-	void SetName( const TCHAR* _name )	{ name = _name; }				///< Set the name of this attribute.
-	void SetValue( const TCHAR* _value )	{ value = _value; }				///< Set the value.
+	void SetName( const wchar_t* _name )	{ name = _name; }				///< Set the name of this attribute.
+	void SetValue( const wchar_t* _value )	{ value = _value; }				///< Set the value.
 
 	void SetIntValue( int value );										///< Set the value from an integer.
 	void SetDoubleValue( double value );								///< Set the value from a double.
 
     #ifdef TIXML_USE_STL
 	/// STL string form.
-	void SetName( const generic_string& _name )	
+	void SetName( const std::wstring& _name )	
 	{	
 		StringToBuffer buf( _name );
 		SetName ( buf.buffer ? buf.buffer : TEXT("error") );	
 	}
 	/// STL string form.	
-	void SetValue( const generic_string& _value )	
+	void SetValue( const std::wstring& _value )	
 	{	
 		StringToBuffer buf( _value );
 		SetValue( buf.buffer ? buf.buffer : TEXT("error") );	
@@ -635,9 +635,9 @@ public:
 
 	/*	[internal use]
 		Attribtue parsing starts: first letter of the name
-						 returns: the next TCHAR after the value end quote
+						 returns: the next wchar_t after the value end quote
 	*/
-	virtual const TCHAR* Parse( const TCHAR* p, TiXmlParsingData* data );
+	virtual const wchar_t* Parse( const wchar_t* p, TiXmlParsingData* data );
 
 	// [internal use]
 	virtual void Print( std::string& outputStream, int depth ) const;
@@ -679,7 +679,7 @@ public:
 
 	TiXmlAttribute* First() const	{ return ( sentinel.next == &sentinel ) ? 0 : sentinel.next; }
 	TiXmlAttribute* Last()  const	{ return ( sentinel.prev == &sentinel ) ? 0 : sentinel.prev; }
-	TiXmlAttribute*	Find( const TCHAR * name ) const;
+	TiXmlAttribute*	Find( const wchar_t * name ) const;
 
 private:
 	TiXmlAttribute sentinel;
@@ -694,11 +694,11 @@ class TiXmlElement : public TiXmlNode
 {
 public:
 	/// Construct an element.
-	TiXmlElement (const TCHAR * in_value);
+	TiXmlElement (const wchar_t * in_value);
 
 	#ifdef TIXML_USE_STL
 	/// string constructor.
-	TiXmlElement( const generic_string& _value ) : 	TiXmlNode( TiXmlNode::ELEMENT )
+	TiXmlElement( const std::wstring& _value ) : 	TiXmlNode( TiXmlNode::ELEMENT )
 	{
 		firstChild = lastChild = 0;
 		value = _value;
@@ -710,7 +710,7 @@ public:
 	/** Given an attribute name, Attribute() returns the value
 		for the attribute of that name, or null if none exists.
 	*/
-	const TCHAR* Attribute( const TCHAR* name ) const;
+	const wchar_t* Attribute( const wchar_t* name ) const;
 
 	/** Given an attribute name, Attribute() returns the value
 		for the attribute of that name, or null if none exists.
@@ -718,7 +718,7 @@ public:
 		the integer value will be put in the return 'i', if 'i'
 		is non-null.
 	*/
-	const TCHAR* Attribute( const TCHAR* name, int* i ) const;
+	const wchar_t* Attribute( const wchar_t* name, int* i ) const;
 
 	/** Given an attribute name, Attribute() returns the value
 		for the attribute of that name, or null if none exists.
@@ -726,7 +726,7 @@ public:
 		the double value will be put in the return 'd', if 'd'
 		is non-null.
 	*/
-	const TCHAR* Attribute( const TCHAR* name, double* d ) const;
+	const wchar_t* Attribute( const wchar_t* name, double* d ) const;
 
 	/** QueryIntAttribute examines the attribute - it is an alternative to the
 		Attribute() method with richer error checking.
@@ -735,21 +735,21 @@ public:
 		an integer, it returns TIXML_WRONG_TYPE. If the attribute
 		does not exist, then TIXML_NO_ATTRIBUTE is returned.
 	*/	
-	int QueryIntAttribute( const TCHAR* name, int* value ) const;
+	int QueryIntAttribute( const wchar_t* name, int* value ) const;
 	/// QueryDoubleAttribute examines the attribute - see QueryIntAttribute().
-	int QueryDoubleAttribute( const TCHAR* name, double* value ) const;
+	int QueryDoubleAttribute( const wchar_t* name, double* value ) const;
 
 	/** Sets an attribute of name to a given value. The attribute
 		will be created if it does not exist, or changed if it does.
 	*/
-	void SetAttribute( const TCHAR* name, const TCHAR * value );
+	void SetAttribute( const wchar_t* name, const wchar_t * value );
 
     #ifdef TIXML_USE_STL
-	const TCHAR* Attribute( const generic_string& name ) const				{ return Attribute( name.c_str() ); }
-	const TCHAR* Attribute( const generic_string& name, int* i ) const		{ return Attribute( name.c_str(), i ); }
+	const wchar_t* Attribute( const std::wstring& name ) const				{ return Attribute( name.c_str() ); }
+	const wchar_t* Attribute( const std::wstring& name, int* i ) const		{ return Attribute( name.c_str(), i ); }
 
 	/// STL string form.
-	void SetAttribute( const generic_string& name, const generic_string& _value )	
+	void SetAttribute( const std::wstring& name, const std::wstring& _value )	
 	{	
 		StringToBuffer n( name );
 		StringToBuffer v( _value );
@@ -757,7 +757,7 @@ public:
 			SetAttribute (n.buffer, v.buffer );	
 	}	
 	///< STL string form.
-	void SetAttribute( const generic_string& name, int _value )	
+	void SetAttribute( const std::wstring& name, int _value )	
 	{	
 		StringToBuffer n( name );
 		if ( n.buffer )
@@ -768,13 +768,13 @@ public:
 	/** Sets an attribute of name to a given value. The attribute
 		will be created if it does not exist, or changed if it does.
 	*/
-	void SetAttribute( const TCHAR * name, int value );
+	void SetAttribute( const wchar_t * name, int value );
 
 	/** Deletes an attribute with the given name.
 	*/
-	void RemoveAttribute( const TCHAR * name );
+	void RemoveAttribute( const wchar_t * name );
     #ifdef TIXML_USE_STL
-	void RemoveAttribute( const generic_string& name )	{	RemoveAttribute (name.c_str ());	}	///< STL string form.
+	void RemoveAttribute( const std::wstring& name )	{	RemoveAttribute (name.c_str ());	}	///< STL string form.
 	#endif
 
 	TiXmlAttribute* FirstAttribute() const	{ return attributeSet.First(); }		///< Access the first attribute in this element.
@@ -795,16 +795,16 @@ protected:
 	virtual void StreamOut( TIXML_OSTREAM * out ) const;
 
 	/*	[internal use]
-		Attribtue parsing starts: next TCHAR past '<'
-						 returns: next TCHAR past '>'
+		Attribtue parsing starts: next wchar_t past '<'
+						 returns: next wchar_t past '>'
 	*/
-	virtual const TCHAR* Parse( const TCHAR* p, TiXmlParsingData* data );
+	virtual const wchar_t* Parse( const wchar_t* p, TiXmlParsingData* data );
 
 	/*	[internal use]
 		Reads the "value" of the element -- another element, or text.
 		This should terminate with the current end tag.
 	*/
-	const TCHAR* ReadValue( const TCHAR* in, TiXmlParsingData* prevData );
+	const wchar_t* ReadValue( const wchar_t* in, TiXmlParsingData* prevData );
 
 private:
 	TiXmlAttributeSet attributeSet;
@@ -832,9 +832,9 @@ protected:
 	virtual void StreamOut( TIXML_OSTREAM * out ) const;
 	/*	[internal use]
 		Attribtue parsing starts: at the ! of the !--
-						 returns: next TCHAR past '>'
+						 returns: next wchar_t past '>'
 	*/
-	virtual const TCHAR* Parse( const TCHAR* p, TiXmlParsingData* data );
+	virtual const wchar_t* Parse( const wchar_t* p, TiXmlParsingData* data );
 };
 
 
@@ -845,7 +845,7 @@ class TiXmlText : public TiXmlNode
 	friend class TiXmlElement;
 public:
 	/// Constructor.
-	TiXmlText (const TCHAR * initValue) : TiXmlNode (TiXmlNode::TEXT)
+	TiXmlText (const wchar_t * initValue) : TiXmlNode (TiXmlNode::TEXT)
 	{
 		SetValue( initValue );
 	}
@@ -853,7 +853,7 @@ public:
 
 	#ifdef TIXML_USE_STL
 	/// Constructor.
-	TiXmlText( const generic_string& initValue ) : TiXmlNode (TiXmlNode::TEXT)
+	TiXmlText( const std::wstring& initValue ) : TiXmlNode (TiXmlNode::TEXT)
 	{
 		SetValue( initValue );
 	}
@@ -869,10 +869,10 @@ protected :
 	// [internal use]
 	bool Blank() const;	// returns true if all white space and new lines
 	/*	[internal use]
-			Attribtue parsing starts: First TCHAR of the text
-							 returns: next TCHAR past '>'
+			Attribtue parsing starts: First wchar_t of the text
+							 returns: next wchar_t past '>'
 	*/
-	virtual const TCHAR* Parse( const TCHAR* p, TiXmlParsingData* data );
+	virtual const wchar_t* Parse( const wchar_t* p, TiXmlParsingData* data );
 	// [internal use]
 	#ifdef TIXML_USE_STL
 	    virtual void StreamIn( TIXML_ISTREAM * in, TIXML_STRING * tag );
@@ -901,9 +901,9 @@ public:
 
 #ifdef TIXML_USE_STL
 	/// Constructor.
-	TiXmlDeclaration(	const generic_string& _version,
-						const generic_string& _encoding,
-						const generic_string& _standalone )
+	TiXmlDeclaration(	const std::wstring& _version,
+						const std::wstring& _encoding,
+						const std::wstring& _standalone )
 			: TiXmlNode( TiXmlNode::DECLARATION )
 	{
 		version = _version;
@@ -913,18 +913,18 @@ public:
 #endif
 
 	/// Construct.
-	TiXmlDeclaration(	const TCHAR* _version,
-						const TCHAR* _encoding,
-						const TCHAR* _standalone );
+	TiXmlDeclaration(	const wchar_t* _version,
+						const wchar_t* _encoding,
+						const wchar_t* _standalone );
 
 	virtual ~TiXmlDeclaration()	{}
 
 	/// Version. Will return empty if none was found.
-	const TCHAR * Version() const		{ return version.c_str (); }
+	const wchar_t * Version() const		{ return version.c_str (); }
 	/// Encoding. Will return empty if none was found.
-	const TCHAR * Encoding() const		{ return encoding.c_str (); }
+	const wchar_t * Encoding() const		{ return encoding.c_str (); }
 	/// Is this a standalone document?
-	const TCHAR * Standalone() const		{ return standalone.c_str (); }
+	const wchar_t * Standalone() const		{ return standalone.c_str (); }
 
 	// [internal use] Creates a new Element and returs it.
 	virtual TiXmlNode* Clone() const;
@@ -938,10 +938,10 @@ protected:
 	#endif
 	virtual void StreamOut ( TIXML_OSTREAM * out) const;
 	//	[internal use]
-	//	Attribtue parsing starts: next TCHAR past '<'
-	//					 returns: next TCHAR past '>'
+	//	Attribtue parsing starts: next wchar_t past '<'
+	//					 returns: next wchar_t past '>'
 
-	virtual const TCHAR* Parse( const TCHAR* p, TiXmlParsingData* data );
+	virtual const wchar_t* Parse( const wchar_t* p, TiXmlParsingData* data );
 
 private:
 	TIXML_STRING version;
@@ -971,10 +971,10 @@ protected:
 	#endif
 	virtual void StreamOut ( TIXML_OSTREAM * out ) const;
 	/*	[internal use]
-		Attribute parsing starts: First TCHAR of the text
-						 returns: next TCHAR past '>'
+		Attribute parsing starts: First wchar_t of the text
+						 returns: next wchar_t past '>'
 	*/
-	virtual const TCHAR* Parse( const TCHAR* p, TiXmlParsingData* data );
+	virtual const wchar_t* Parse( const wchar_t* p, TiXmlParsingData* data );
 };
 
 
@@ -988,11 +988,11 @@ public:
 	/// Create an empty document, that has no name.
 	TiXmlDocument();
 	/// Create a document with a name. The name of the document is also the filename of the xml.
-	TiXmlDocument( const TCHAR * documentName );
+	TiXmlDocument( const wchar_t * documentName );
 
 	#ifdef TIXML_USE_STL
 	/// Constructor.
-	TiXmlDocument( const generic_string& documentName ) :
+	TiXmlDocument( const std::wstring& documentName ) :
 	    TiXmlNode( TiXmlNode::DOCUMENT )
 	{
 		tabsize = 4;
@@ -1011,17 +1011,17 @@ public:
 	/// Save a file using the current document value. Returns true if successful.
 	bool SaveFile() const;
 	/// Load a file using the given filename. Returns true if successful.
-	bool LoadFile( const TCHAR * filename );
+	bool LoadFile( const wchar_t * filename );
 	/// Save a file using the given filename. Returns true if successful.
-	bool SaveFile( const TCHAR * filename ) const;
+	bool SaveFile( const wchar_t * filename ) const;
 
 	#ifdef TIXML_USE_STL
-	bool LoadFile( const generic_string& filename )			///< STL string version.
+	bool LoadFile( const std::wstring& filename )			///< STL string version.
 	{
 		StringToBuffer f( filename );
 		return ( f.buffer && LoadFile( f.buffer ));
 	}
-	bool SaveFile( const generic_string& filename ) const		///< STL string version.
+	bool SaveFile( const std::wstring& filename ) const		///< STL string version.
 	{
 		StringToBuffer f( filename );
 		return ( f.buffer && SaveFile( f.buffer ));
@@ -1030,7 +1030,7 @@ public:
 
 	/** Parse the given null terminated block of xml data.
 	*/
-	virtual const TCHAR* Parse( const TCHAR* p, TiXmlParsingData* data = 0 );
+	virtual const wchar_t* Parse( const wchar_t* p, TiXmlParsingData* data = 0 );
 
 	/** Get the root element -- the only top level element -- of the document.
 		In well formed XML, there should only be one. TinyXml is tolerant of
@@ -1046,9 +1046,9 @@ public:
 	bool Error() const						{ return error; }
 
 	/// Contains a textual (english) description of the error if one occurs.
-	const TCHAR * ErrorDesc() const	{ return errorDesc.c_str (); }
+	const wchar_t * ErrorDesc() const	{ return errorDesc.c_str (); }
 
-	/** Generally, you probably want the error generic_string ( ErrorDesc() ). But if you
+	/** Generally, you probably want the error std::wstring ( ErrorDesc() ). But if you
 		prefer the ErrorId, this function will fetch it.
 	*/
 	int ErrorId()	const					{ return errorId; }
@@ -1103,7 +1103,7 @@ public:
 	// [internal use]
 	virtual void Print( std::string& outputStream, int depth = 0 ) const;
 	// [internal use]
-	void SetError( int err, const TCHAR* errorLocation, TiXmlParsingData* prevData );
+	void SetError( int err, const wchar_t* errorLocation, TiXmlParsingData* prevData );
 
 protected :
 	virtual void StreamOut ( TIXML_OSTREAM * out) const;
@@ -1213,16 +1213,16 @@ public:
 	/// Return a handle to the first child node.
 	TiXmlHandle FirstChild() const;
 	/// Return a handle to the first child node with the given name.
-	TiXmlHandle FirstChild( const TCHAR * value ) const;
+	TiXmlHandle FirstChild( const wchar_t * value ) const;
 	/// Return a handle to the first child element.
 	TiXmlHandle FirstChildElement() const;
 	/// Return a handle to the first child element with the given name.
-	TiXmlHandle FirstChildElement( const TCHAR * value ) const;
+	TiXmlHandle FirstChildElement( const wchar_t * value ) const;
 
 	/** Return a handle to the "index" child with the given name. 
 		The first child is 0, the second 1, etc.
 	*/
-	TiXmlHandle Child( const TCHAR* value, int index ) const;
+	TiXmlHandle Child( const wchar_t* value, int index ) const;
 	/** Return a handle to the "index" child. 
 		The first child is 0, the second 1, etc.
 	*/
@@ -1231,7 +1231,7 @@ public:
 		The first child element is 0, the second 1, etc. Note that only TiXmlElements
 		are indexed: other types are not counted.
 	*/
-	TiXmlHandle ChildElement( const TCHAR* value, int index ) const;
+	TiXmlHandle ChildElement( const wchar_t* value, int index ) const;
 	/** Return a handle to the "index" child element. 
 		The first child element is 0, the second 1, etc. Note that only TiXmlElements
 		are indexed: other types are not counted.
@@ -1239,11 +1239,11 @@ public:
 	TiXmlHandle ChildElement( int index ) const;
 
 	#ifdef TIXML_USE_STL
-	TiXmlHandle FirstChild( const generic_string& _value ) const			{ return FirstChild( _value.c_str() ); }
-	TiXmlHandle FirstChildElement( const generic_string& _value ) const		{ return FirstChildElement( _value.c_str() ); }
+	TiXmlHandle FirstChild( const std::wstring& _value ) const			{ return FirstChild( _value.c_str() ); }
+	TiXmlHandle FirstChildElement( const std::wstring& _value ) const		{ return FirstChildElement( _value.c_str() ); }
 
-	TiXmlHandle Child( const generic_string& _value, int index ) const			{ return Child( _value.c_str(), index ); }
-	TiXmlHandle ChildElement( const generic_string& _value, int index ) const	{ return ChildElement( _value.c_str(), index ); }
+	TiXmlHandle Child( const std::wstring& _value, int index ) const			{ return Child( _value.c_str(), index ); }
+	TiXmlHandle ChildElement( const std::wstring& _value, int index ) const	{ return ChildElement( _value.c_str(), index ); }
 	#endif
 
 	/// Return the handle as a TiXmlNode. This may return null.
