@@ -481,6 +481,12 @@
 	#define IDC_RADIO_DARKMODE_DARKMODE    (IDD_PREFERENCE_SUB_DARKMODE + 32)
 	#define IDC_RADIO_DARKMODE_FOLLOWWINDOWS  (IDD_PREFERENCE_SUB_DARKMODE + 33)
 	#define IDC_DARKMODE_TONES_GB_STATIC   (IDD_PREFERENCE_SUB_DARKMODE + 35)
+	#define IDD_DROPDOWN_RESET_RED         (IDD_PREFERENCE_SUB_DARKMODE + 36)
+	#define IDD_DROPDOWN_RESET_GREEN       (IDD_PREFERENCE_SUB_DARKMODE + 37)
+	#define IDD_DROPDOWN_RESET_BLUE        (IDD_PREFERENCE_SUB_DARKMODE + 38)
+	#define IDD_DROPDOWN_RESET_PURPLE      (IDD_PREFERENCE_SUB_DARKMODE + 39)
+	#define IDD_DROPDOWN_RESET_CYAN        (IDD_PREFERENCE_SUB_DARKMODE + 40)
+	#define IDD_DROPDOWN_RESET_OLIVE       (IDD_PREFERENCE_SUB_DARKMODE + 41)
 
 #define IDD_PREFERENCE_SUB_PERFORMANCE 7140 //(IDD_PREFERENCE_BOX + 1100)
 	#define IDC_GROUPSTATIC_PERFORMANCE_RESTRICTION     (IDD_PREFERENCE_SUB_PERFORMANCE + 1)
