@@ -721,7 +721,7 @@ void Splitter::adjustZoneToDraw(RECT& rc2def, ZONE_TYPE whichZone)
 
 	int x0, y0, x1, y1, w, h;
 
-	if ((4 <= _splitterSize) && (_splitterSize <= 8))
+	if (/*(4 <= _splitterSize) && */(_splitterSize <= 8))
 	{
 		w = (isVertical() ? 4 : 7);
 		h = (isVertical() ? 7 : 4);
