@@ -19,14 +19,14 @@
 //
 // Notepad++ version: begin
 //
-#define NOTEPAD_PLUS_VERSION TEXT("Notepad++ v8.6.8")
+#define NOTEPAD_PLUS_VERSION TEXT("Notepad++ v8.6.9")
 
 // should be X.Y : ie. if VERSION_DIGITALVALUE == 4, 7, 1, 0 , then X = 4, Y = 71
 // ex : #define VERSION_VALUE TEXT("5.63\0")
-#define VERSION_INTERNAL_VALUE TEXT("8.68\0")
+#define VERSION_INTERNAL_VALUE TEXT("8.69\0")
 
-#define VERSION_PRODUCT_VALUE TEXT("8.6.8\0")
-#define VERSION_DIGITALVALUE 8, 6, 8, 0
+#define VERSION_PRODUCT_VALUE TEXT("8.6.9\0")
+#define VERSION_DIGITALVALUE 8, 6, 9, 0
 
 // Notepad++ version: end
 
@@ -265,7 +265,6 @@
 #define IDI_UNSAVED_DM_ICON      510
 #define IDI_MONITORING_DM_ICON   511
 #define IDI_READONLY_DM_ICON     512
-#define IDI_DELETE_ICON          525
 
 
 #define IDI_PROJECT_WORKSPACE          601
@@ -374,6 +373,8 @@
 #define IDR_CLIPBOARDPANEL_ICO_DM 1561
 #define IDR_ASCIIPANEL_ICO2       1562
 #define IDR_ASCIIPANEL_ICO_DM     1563
+#define IDR_FIND_RESULT_ICO2      1564
+#define IDR_FIND_RESULT_ICO_DM    1565
 
 #define ID_MACRO                           20000
 //                                     O     .
@@ -616,8 +617,8 @@
 	#define NPPM_INTERNAL_PLUGINSHORTCUTMOTIFIED        (NOTEPADPLUS_USER_INTERNAL + 26)
 	#define NPPM_INTERNAL_SCINTILLAFINDERCLEARALL       (NOTEPADPLUS_USER_INTERNAL + 27)
 	#define NPPM_INTERNAL_CHANGETABBARICONSET           (NOTEPADPLUS_USER_INTERNAL + 28)
-	#define NPPM_INTERNAL_SETTING_TAB_REPLCESPACE       (NOTEPADPLUS_USER_INTERNAL + 29)
-	#define NPPM_INTERNAL_SETTING_TAB_SIZE              (NOTEPADPLUS_USER_INTERNAL + 30)
+	#define NPPM_INTERNAL_SET_TAB_SETTINGS              (NOTEPADPLUS_USER_INTERNAL + 29)
+	//#define NPPM_INTERNAL_SETTING_TAB_SIZE            (NOTEPADPLUS_USER_INTERNAL + 30)
 	#define NPPM_INTERNAL_RELOADSTYLERS                 (NOTEPADPLUS_USER_INTERNAL + 31)
 	#define NPPM_INTERNAL_DOCORDERCHANGED               (NOTEPADPLUS_USER_INTERNAL + 32)
 	#define NPPM_INTERNAL_SETMULTISELCTION              (NOTEPADPLUS_USER_INTERNAL + 33)
@@ -687,14 +688,6 @@
     	#define CHECKDOCOPT_UPDATESILENTLY 1
     	#define CHECKDOCOPT_UPDATEGO2END 2
 
-    //
-    // Used by netnote plugin
-    //
-	#define NPPM_INTERNAL_SETFILENAME (NPPMSG + 63)
-    //wParam: BufferID to rename
-    //lParam: name to set (TCHAR*)
-    //Buffer must have been previously unnamed (eg "new 1" document types)
-
 
 
 #define SCINTILLA_USER     (WM_USER + 2000)
