@@ -42,7 +42,7 @@ void allowPrivilegeMessages(const Notepad_plus_Window& notepad_plus_plus, winVer
 	// This (WM_COPYDATA) allows opening new files to already opened elevated Notepad++ process via explorer context menu.
 	if (winVer >= WV_VISTA || winVer == WV_UNKNOWN)
 	{
-		HMODULE hDll = GetModuleHandle(TEXT("user32.dll"));
+		HMODULE hDll = GetModuleHandle(L"user32.dll");
 		if (hDll)
 		{
 			// According to MSDN ChangeWindowMessageFilter may not be supported in future versions of Windows,
@@ -83,15 +83,15 @@ void allowPrivilegeMessages(const Notepad_plus_Window& notepad_plus_plus, winVer
 // 2. "-z"
 // 3. "C:\WINDOWS\system32\NOTEPAD.EXE"
 // 4. "C:\my folder\my file with whitespace.txt" 
-void parseCommandLine(const TCHAR* commandLine, ParamVector& paramVector)
+void parseCommandLine(const wchar_t* commandLine, ParamVector& paramVector)
 {
 	if (!commandLine)
 		return;
 	
-	TCHAR* cmdLine = new TCHAR[lstrlen(commandLine) + 1];
+	wchar_t* cmdLine = new wchar_t[lstrlen(commandLine) + 1];
 	lstrcpy(cmdLine, commandLine);
 
-	TCHAR* cmdLinePtr = cmdLine;
+	wchar_t* cmdLinePtr = cmdLine;
 
 	bool isBetweenFileNameQuotes = false;
 	bool isStringInArg = false;
@@ -105,7 +105,7 @@ void parseCommandLine(const TCHAR* commandLine, ParamVector& paramVector)
 	                                 // when zArg == 2 shouldBeTerminated will be set to true - it will trigger the treatment which consider the rest as a argument, with or without white space(s).
 
 	size_t commandLength = lstrlen(cmdLinePtr);
-	std::vector<TCHAR *> args;
+	std::vector<wchar_t *> args;
 	for (size_t i = 0; i < commandLength && !shouldBeTerminated; ++i)
 	{
 		switch (cmdLinePtr[i])
@@ -156,7 +156,7 @@ void parseCommandLine(const TCHAR* commandLine, ParamVector& paramVector)
 			}
 			break;
 
-			default: //default TCHAR, if beginning of word, add it
+			default: //default wchar_t, if beginning of word, add it
 			{
 				if (!isBetweenFileNameQuotes && !isStringInArg && isInWhiteSpace)
 				{
@@ -181,14 +181,14 @@ void convertParamsToNotepadStyle(ParamVector& params)
 {
 	for (auto it = params.begin(); it != params.end(); ++it)
 	{
-		if (lstrcmp(it->c_str(), TEXT("/p")) == 0 || lstrcmp(it->c_str(), TEXT("/P")) == 0)
+		if (lstrcmp(it->c_str(), L"/p") == 0 || lstrcmp(it->c_str(), L"/P") == 0)
 		{
-			it->assign(TEXT("-quickPrint"));
+			it->assign(L"-quickPrint");
 		}
 	}
 }
 
-bool isInList(const TCHAR *token2Find, ParamVector& params, bool eraseArg = true)
+bool isInList(const wchar_t *token2Find, ParamVector& params, bool eraseArg = true)
 {
 	for (auto it = params.begin(); it != params.end(); ++it)
 	{
@@ -201,14 +201,14 @@ bool isInList(const TCHAR *token2Find, ParamVector& params, bool eraseArg = true
 	return false;
 }
 
-bool getParamVal(TCHAR c, ParamVector & params, std::wstring & value)
+bool getParamVal(wchar_t c, ParamVector & params, std::wstring & value)
 {
-	value = TEXT("");
+	value = L"";
 	size_t nbItems = params.size();
 
 	for (size_t i = 0; i < nbItems; ++i)
 	{
-		const TCHAR * token = params.at(i).c_str();
+		const wchar_t * token = params.at(i).c_str();
 		if (token[0] == '-' && lstrlen(token) >= 2 && token[1] == c) //dash, and enough chars
 		{
 			value = (token+2);
@@ -219,14 +219,14 @@ bool getParamVal(TCHAR c, ParamVector & params, std::wstring & value)
 	return false;
 }
 
-bool getParamValFromString(const TCHAR *str, ParamVector & params, std::wstring & value)
+bool getParamValFromString(const wchar_t *str, ParamVector & params, std::wstring & value)
 {
-	value = TEXT("");
+	value = L"";
 	size_t nbItems = params.size();
 
 	for (size_t i = 0; i < nbItems; ++i)
 	{
-		const TCHAR * token = params.at(i).c_str();
+		const wchar_t * token = params.at(i).c_str();
 		std::wstring tokenStr = token;
 		size_t pos = tokenStr.find(str);
 		if (pos != std::wstring::npos && pos == 0)
@@ -251,8 +251,8 @@ std::wstring getLocalizationPathFromParam(ParamVector & params)
 {
 	std::wstring locStr;
 	if (!getParamVal('L', params, locStr))
-		return TEXT("");
-	locStr = stringToLower(stringReplace(locStr, TEXT("_"), TEXT("-"))); // convert to lowercase format with "-" as separator
+		return L"";
+	locStr = stringToLower(stringReplace(locStr, L"_", L"-")); // convert to lowercase format with "-" as separator
 	return NppParameters::getLocPathFromStr(locStr.c_str());
 }
 
@@ -271,12 +271,12 @@ intptr_t getNumberFromParam(char paramName, ParamVector & params, bool & isParam
 std::wstring getEasterEggNameFromParam(ParamVector & params, unsigned char & type)
 {
 	std::wstring EasterEggName;
-	if (!getParamValFromString(TEXT("-qn="), params, EasterEggName))  // get internal easter egg
+	if (!getParamValFromString(L"-qn=", params, EasterEggName))  // get internal easter egg
 	{
-		if (!getParamValFromString(TEXT("-qt="), params, EasterEggName)) // get user quote from cmdline argument
+		if (!getParamValFromString(L"-qt=", params, EasterEggName)) // get user quote from cmdline argument
 		{
-			if (!getParamValFromString(TEXT("-qf="), params, EasterEggName)) // get user quote from a content of file
-				return TEXT("");
+			if (!getParamValFromString(L"-qf=", params, EasterEggName)) // get user quote from a content of file
+				return L"";
 			else
 			{
 				type = 2; // quote content in file
@@ -302,7 +302,7 @@ std::wstring getEasterEggNameFromParam(ParamVector & params, unsigned char & typ
 int getGhostTypingSpeedFromParam(ParamVector & params)
 {
 	std::wstring speedStr;
-	if (!getParamValFromString(TEXT("-qSpeed"), params, speedStr))
+	if (!getParamValFromString(L"-qSpeed", params, speedStr))
 		return -1;
 	
 	int speed = std::stoi(speedStr, 0);
@@ -312,46 +312,46 @@ int getGhostTypingSpeedFromParam(ParamVector & params)
 	return speed;
 }
 
-const TCHAR FLAG_MULTI_INSTANCE[] = TEXT("-multiInst");
-const TCHAR FLAG_NO_PLUGIN[] = TEXT("-noPlugin");
-const TCHAR FLAG_READONLY[] = TEXT("-ro");
-const TCHAR FLAG_NOSESSION[] = TEXT("-nosession");
-const TCHAR FLAG_NOTABBAR[] = TEXT("-notabbar");
-const TCHAR FLAG_SYSTRAY[] = TEXT("-systemtray");
-const TCHAR FLAG_LOADINGTIME[] = TEXT("-loadingTime");
-const TCHAR FLAG_HELP[] = TEXT("--help");
-const TCHAR FLAG_ALWAYS_ON_TOP[] = TEXT("-alwaysOnTop");
-const TCHAR FLAG_OPENSESSIONFILE[] = TEXT("-openSession");
-const TCHAR FLAG_RECURSIVE[] = TEXT("-r");
-const TCHAR FLAG_FUNCLSTEXPORT[] = TEXT("-export=functionList");
-const TCHAR FLAG_PRINTANDQUIT[] = TEXT("-quickPrint");
-const TCHAR FLAG_NOTEPAD_COMPATIBILITY[] = TEXT("-notepadStyleCmdline");
-const TCHAR FLAG_OPEN_FOLDERS_AS_WORKSPACE[] = TEXT("-openFoldersAsWorkspace");
-const TCHAR FLAG_SETTINGS_DIR[] = TEXT("-settingsDir=");
-const TCHAR FLAG_TITLEBAR_ADD[] = TEXT("-titleAdd=");
-const TCHAR FLAG_APPLY_UDL[] = TEXT("-udl=");
-const TCHAR FLAG_PLUGIN_MESSAGE[] = TEXT("-pluginMessage=");
-const TCHAR FLAG_MONITOR_FILES[] = TEXT("-monitor");
+const wchar_t FLAG_MULTI_INSTANCE[] = L"-multiInst";
+const wchar_t FLAG_NO_PLUGIN[] = L"-noPlugin";
+const wchar_t FLAG_READONLY[] = L"-ro";
+const wchar_t FLAG_NOSESSION[] = L"-nosession";
+const wchar_t FLAG_NOTABBAR[] = L"-notabbar";
+const wchar_t FLAG_SYSTRAY[] = L"-systemtray";
+const wchar_t FLAG_LOADINGTIME[] = L"-loadingTime";
+const wchar_t FLAG_HELP[] = L"--help";
+const wchar_t FLAG_ALWAYS_ON_TOP[] = L"-alwaysOnTop";
+const wchar_t FLAG_OPENSESSIONFILE[] = L"-openSession";
+const wchar_t FLAG_RECURSIVE[] = L"-r";
+const wchar_t FLAG_FUNCLSTEXPORT[] = L"-export=functionList";
+const wchar_t FLAG_PRINTANDQUIT[] = L"-quickPrint";
+const wchar_t FLAG_NOTEPAD_COMPATIBILITY[] = L"-notepadStyleCmdline";
+const wchar_t FLAG_OPEN_FOLDERS_AS_WORKSPACE[] = L"-openFoldersAsWorkspace";
+const wchar_t FLAG_SETTINGS_DIR[] = L"-settingsDir=";
+const wchar_t FLAG_TITLEBAR_ADD[] = L"-titleAdd=";
+const wchar_t FLAG_APPLY_UDL[] = L"-udl=";
+const wchar_t FLAG_PLUGIN_MESSAGE[] = L"-pluginMessage=";
+const wchar_t FLAG_MONITOR_FILES[] = L"-monitor";
 
 void doException(Notepad_plus_Window & notepad_plus_plus)
 {
 	Win32Exception::removeHandler();	//disable exception handler after excpetion, we dont want corrupt data structurs to crash the exception handler
-	::MessageBox(Notepad_plus_Window::gNppHWND, TEXT("Notepad++ will attempt to save any unsaved data. However, dataloss is very likely."), TEXT("Recovery initiating"), MB_OK | MB_ICONINFORMATION);
+	::MessageBox(Notepad_plus_Window::gNppHWND, L"Notepad++ will attempt to save any unsaved data. However, dataloss is very likely.", L"Recovery initiating", MB_OK | MB_ICONINFORMATION);
 
-	TCHAR tmpDir[1024];
+	wchar_t tmpDir[1024];
 	GetTempPath(1024, tmpDir);
 	std::wstring emergencySavedDir = tmpDir;
-	emergencySavedDir += TEXT("\\Notepad++ RECOV");
+	emergencySavedDir += L"\\Notepad++ RECOV";
 
 	bool res = notepad_plus_plus.emergency(emergencySavedDir);
 	if (res)
 	{
-		std::wstring displayText = TEXT("Notepad++ was able to successfully recover some unsaved documents, or nothing to be saved could be found.\r\nYou can find the results at :\r\n");
+		std::wstring displayText = L"Notepad++ was able to successfully recover some unsaved documents, or nothing to be saved could be found.\r\nYou can find the results at :\r\n";
 		displayText += emergencySavedDir;
-		::MessageBox(Notepad_plus_Window::gNppHWND, displayText.c_str(), TEXT("Recovery success"), MB_OK | MB_ICONINFORMATION);
+		::MessageBox(Notepad_plus_Window::gNppHWND, displayText.c_str(), L"Recovery success", MB_OK | MB_ICONINFORMATION);
 	}
 	else
-		::MessageBox(Notepad_plus_Window::gNppHWND, TEXT("Unfortunatly, Notepad++ was not able to save your work. We are sorry for any lost data."), TEXT("Recovery failure"), MB_OK | MB_ICONERROR);
+		::MessageBox(Notepad_plus_Window::gNppHWND, L"Unfortunatly, Notepad++ was not able to save your work. We are sorry for any lost data.", L"Recovery failure", MB_OK | MB_ICONERROR);
 }
 
 // Looks for -z arguments and strips command line arguments following those, if any
@@ -359,7 +359,7 @@ void stripIgnoredParams(ParamVector & params)
 {
 	for (auto it = params.begin(); it != params.end(); )
 	{
-		if (lstrcmp(it->c_str(), TEXT("-z")) == 0)
+		if (lstrcmp(it->c_str(), L"-z") == 0)
 		{
 			auto nextIt = std::next(it);
 			if ( nextIt != params.end() )
@@ -387,11 +387,11 @@ int WINAPI wWinMain(_In_ HINSTANCE hInstance, _In_opt_ HINSTANCE /*hPrevInstance
 
 	bool TheFirstOne = true;
 	::SetLastError(NO_ERROR);
-	::CreateMutex(NULL, false, TEXT("nppInstance"));
+	::CreateMutex(NULL, false, L"nppInstance");
 	if (::GetLastError() == ERROR_ALREADY_EXISTS)
 		TheFirstOne = false;
 
-	std::wstring cmdLineString = pCmdLine ? pCmdLine : _T("");
+	std::wstring cmdLineString = pCmdLine ? pCmdLine : L"";
 	ParamVector params;
 	parseCommandLine(pCmdLine, params);
 
@@ -490,9 +490,9 @@ int WINAPI wWinMain(_In_ HINSTANCE hInstance, _In_opt_ HINSTANCE /*hPrevInstance
 	}
 
 	if (showHelp)
-		::MessageBox(NULL, COMMAND_ARG_HELP, TEXT("Notepad++ Command Argument Help"), MB_OK);
+		::MessageBox(NULL, COMMAND_ARG_HELP, L"Notepad++ Command Argument Help", MB_OK);
 
-	if (cmdLineParams._localizationPath != TEXT(""))
+	if (cmdLineParams._localizationPath != L"")
 	{
 		// setStartWithLocFileName() should be called before parameters are loaded
 		nppParameters.setStartWithLocFileName(cmdLineParams._localizationPath);
@@ -536,20 +536,20 @@ int WINAPI wWinMain(_In_ HINSTANCE hInstance, _In_opt_ HINSTANCE /*hPrevInstance
 			cmdLineParams._isNoSession = true;
 	}
 
-	std::wstring quotFileName = TEXT("");
+	std::wstring quotFileName = L"";
     // tell the running instance the FULL path to the new files to load
 	size_t nbFilesToOpen = params.size();
 
 	for (size_t i = 0; i < nbFilesToOpen; ++i)
 	{
-		const TCHAR * currentFile = params.at(i).c_str();
+		const wchar_t * currentFile = params.at(i).c_str();
 		if (currentFile[0])
 		{
 			//check if relative or full path. Relative paths dont have a colon for driveletter
 
-			quotFileName += TEXT("\"");
+			quotFileName += L"\"";
 			quotFileName += relativeFilePathToFullFilePath(currentFile);
-			quotFileName += TEXT("\" ");
+			quotFileName += L"\" ";
 		}
 	}
 
@@ -600,13 +600,13 @@ int WINAPI wWinMain(_In_ HINSTANCE hInstance, _In_opt_ HINSTANCE /*hPrevInstance
 				COPYDATASTRUCT cmdLineData{};
 				cmdLineData.dwData = COPYDATA_FULL_CMDLINE;
 				cmdLineData.lpData = (void*)cmdLineString.c_str();
-				cmdLineData.cbData = static_cast<DWORD>((cmdLineString.length() + 1) * sizeof(TCHAR));
+				cmdLineData.cbData = static_cast<DWORD>((cmdLineString.length() + 1) * sizeof(wchar_t));
 				::SendMessage(hNotepad_plus, WM_COPYDATA, reinterpret_cast<WPARAM>(hInstance), reinterpret_cast<LPARAM>(&cmdLineData));
 
 				COPYDATASTRUCT fileNamesData{};
 				fileNamesData.dwData = COPYDATA_FILENAMESW;
 				fileNamesData.lpData = (void *)quotFileName.c_str();
-				fileNamesData.cbData = static_cast<DWORD>((quotFileName.length() + 1) * sizeof(TCHAR));
+				fileNamesData.cbData = static_cast<DWORD>((quotFileName.length() + 1) * sizeof(wchar_t));
 				::SendMessage(hNotepad_plus, WM_COPYDATA, reinterpret_cast<WPARAM>(hInstance), reinterpret_cast<LPARAM>(&fileNamesData));
 			}
 			return 0;
@@ -617,11 +617,11 @@ int WINAPI wWinMain(_In_ HINSTANCE hInstance, _In_opt_ HINSTANCE /*hPrevInstance
 	Notepad_plus_Window & notepad_plus_plus = *upNotepadWindow.get();
 
 	std::wstring updaterDir = nppParameters.getNppPath();
-	updaterDir += TEXT("\\updater\\");
+	updaterDir += L"\\updater\\";
 
-	std::wstring updaterFullPath = updaterDir + TEXT("gup.exe");
+	std::wstring updaterFullPath = updaterDir + L"gup.exe";
 
-	std::wstring updaterParams = TEXT("-v");
+	std::wstring updaterParams = L"-v";
 	updaterParams += VERSION_INTERNAL_VALUE;
 
 	bool isUpExist = nppGui._doesExistUpdater = (::PathFileExists(updaterFullPath.c_str()) == TRUE);
@@ -650,11 +650,11 @@ int WINAPI wWinMain(_In_ HINSTANCE hInstance, _In_opt_ HINSTANCE /*hPrevInstance
 	{
 		if (nppParameters.archType() == IMAGE_FILE_MACHINE_AMD64)
 		{
-			updaterParams += TEXT(" -px64");
+			updaterParams += L" -px64";
 		}
 		else if (nppParameters.archType() == IMAGE_FILE_MACHINE_ARM64)
 		{
-			updaterParams += TEXT(" -parm64");
+			updaterParams += L" -parm64";
 		}
 
 		if (doUpdateNpp)
@@ -674,22 +674,22 @@ int WINAPI wWinMain(_In_ HINSTANCE hInstance, _In_opt_ HINSTANCE /*hPrevInstance
 		if (doUpdatePluginList)
 		{
 			// Update Plugin List
-			std::wstring upPlParams = TEXT("-v"); 
+			std::wstring upPlParams = L"-v"; 
 			upPlParams += notepad_plus_plus.getPluginListVerStr();
 
 			if (nppParameters.archType() == IMAGE_FILE_MACHINE_AMD64)
 			{
-				upPlParams += TEXT(" -px64");
+				upPlParams += L" -px64";
 			}
 			else if (nppParameters.archType() == IMAGE_FILE_MACHINE_ARM64)
 			{
-				upPlParams += TEXT(" -parm64");
+				upPlParams += L" -parm64";
 			}
 
-			upPlParams += TEXT(" -upZip");
+			upPlParams += L" -upZip";
 
 			// overrided "InfoUrl" in gup.xml
-			upPlParams += TEXT(" https://notepad-plus-plus.org/update/pluginListDownloadUrl.php");
+			upPlParams += L" https://notepad-plus-plus.org/update/pluginListDownloadUrl.php";
 
 			// indicate the pluginList installation location
 			upPlParams += nppParameters.getPluginConfDir();
@@ -731,10 +731,10 @@ int WINAPI wWinMain(_In_ HINSTANCE hInstance, _In_opt_ HINSTANCE /*hPrevInstance
 	catch (int i)
 	{
 		wchar_t str[50] = L"God Damned Exception:";
-		TCHAR code[10];
-		wsprintf(code, TEXT("%d"), i);
+		wchar_t code[10];
+		wsprintf(code, L"%d", i);
 		wcscat_s(str, code);
-		::MessageBox(Notepad_plus_Window::gNppHWND, str, TEXT("Int Exception"), MB_OK);
+		::MessageBox(Notepad_plus_Window::gNppHWND, str, L"Int Exception", MB_OK);
 		doException(notepad_plus_plus);
 	}
 	catch (std::runtime_error & ex)
@@ -744,10 +744,10 @@ int WINAPI wWinMain(_In_ HINSTANCE hInstance, _In_opt_ HINSTANCE /*hPrevInstance
 	}
 	catch (const Win32Exception & ex)
 	{
-		TCHAR message[1024];	//TODO: sane number
-		wsprintf(message, TEXT("An exception occured. Notepad++ cannot recover and must be shut down.\r\nThe exception details are as follows:\r\n")
-			TEXT("Code:\t0x%08X\r\nType:\t%S\r\nException address: 0x%p"), ex.code(), ex.what(), ex.where());
-		::MessageBox(Notepad_plus_Window::gNppHWND, message, TEXT("Win32Exception"), MB_OK | MB_ICONERROR);
+		wchar_t message[1024];	//TODO: sane number
+		wsprintf(message, L"An exception occured. Notepad++ cannot recover and must be shut down.\r\nThe exception details are as follows:\r\n"
+			L"Code:\t0x%08X\r\nType:\t%S\r\nException address: 0x%p", ex.code(), ex.what(), ex.where());
+		::MessageBox(Notepad_plus_Window::gNppHWND, message, L"Win32Exception", MB_OK | MB_ICONERROR);
 		mdump.writeDump(ex.info());
 		doException(notepad_plus_plus);
 	}
